@@ -53,7 +53,8 @@ def text_decorate(string: str, decoration: str="BOLD"):
 
 def get_funcs(ignore_char: str="_"):
     funcs = []
-    for key, value in globals().items():
+    r = globals().items() + locals().items()
+    for key, value in r:
         if callable(value) and value.__module__ == __name__ and not re.match(f"^{ignore_char}.*", key):
                 funcs.append(value)
     return funcs
